
# Slot: singular_name


a name that is used in the singular form

URI: [linkml:singular_name](https://w3id.org/linkml/singular_name)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:altLabel |

